#!/bin/bash

# Autor: Tino Schuldt
# Date: 30.11.2017
# Info: Installation by source: http://doc.mapbender3.org/en/book/installation/installation_ubuntu.html


# Filename of this script
log_name="config_mapbender3"

# Load the project functions and configuration 
source ./head_admin.sh

# Function to install the packages in the configuration
(
# Enable modul rewrite
a2enmod rewrite

# Unpack to the tmp directory
echo "LOG: unpack Mapbender ($pkg_mapbender.tar.gz)"
cd ../tmp
tar -xzf ../download/$pkg_mapbender.tar.gz

# Copy mapbender3 project to apache2 root directory
mv $pkg_mapbender $path_apache_doc_root/$var_url_mapbender

# Create mapbender3 to Apache2 sites-available
output=$path_sitesavailable/$var_sitesavailable_mapbender
echo "Alias /$var_url_mapbender /var/www/mapbender3/web/" > $output
echo "<Directory /var/www/mapbender3/web/>" >> $output
echo " Options MultiViews FollowSymLinks" >> $output
echo " DirectoryIndex app.php" >> $output
echo " AllowOverride none" >> $output
echo " Order allow,deny" >> $output
echo " Allow from all" >> $output
echo " " >> $output
echo " RewriteEngine On" >> $output
echo " RewriteBase /$var_url_mapbender/" >> $output
echo " RewriteCond %{REQUEST_FILENAME} !-f" >> $output
echo " RewriteRule ^(.*)$ app.php [QSA,L]" >> $output
echo "</Directory>" >> $output

# Enable a2ensite
a2ensite $var_sitesavailable_mapbender

# Reload Apache2
service apache2 reload

# Change permissions
chmod -R ugo+r $path_apache_doc_root/$var_url_mapbender
chown -R www-data:www-data $path_apache_doc_root/$var_url_mapbender
chmod -R ug+w $path_apache_doc_root/$var_url_mapbender/web/uploads

# Create parameters.yml for database connection
cp $path_apache_doc_root/$var_url_mapbender/app/config/parameters.yml.dist $path_apache_doc_root/$var_url_mapbender/app/config/parameters.yml
# Edit parameters.yml to connection with postgres and a new connection for search and digitizer 
echo "parameters:" > parameters.yml
echo "    # EDIT: Mapbender3 database connection" >> parameters.yml
echo "    database_driver:   pdo_pgsql" >> parameters.yml
echo "    database_host:     $var_db_host" >> parameters.yml
echo "    database_port:     $var_db_port" >> parameters.yml
echo "    database_name:     $var_dbm_name" >> parameters.yml
echo "    database_path:     ~" >> parameters.yml
echo "    database_user:     $var_db_user" >> parameters.yml
echo "    database_password: $var_db_password" >> parameters.yml

# only for elements like searchrouter, digitizer
#echo "" >> parameters.yml
#echo "    # EDIT: Database connection to postgis" >> parameters.yml
#echo "    postgis_database_driver:   pdo_pgsql" >> parameters.yml
#echo "    postgis_database_host:     $var_db_host" >> parameters.yml
#echo "    postgis_database_port:     $var_db_port" >> parameters.yml
#echo "    postgis_database_name:     $var_db_name" >> parameters.yml
#echo "    postgis_database_path:     ~" >> parameters.yml
#echo "    postgis_database_user:     $var_db_user" >> parameters.yml
#echo "    postgis_database_password: $var_db_password" >> parameters.yml

tail -n+9 $path_apache_doc_root/$var_url_mapbender/app/config/parameters.yml.dist >> parameters.yml
mv parameters.yml $path_apache_doc_root/$var_url_mapbender/app/config/parameters.yml

# only for elements like searchrouter, digitizer
# Edit config.yml to new connection for search or digitizer (Add text between the lines 57 and 58 "profiling: %kernel.debug%" / "orm:")
#cp $path_apache_doc_root/$var_url_mapbender/app/config/config.yml $path_apache_doc_root/$var_url_mapbender/app/config/config.yml.dist
#head -n+57 $path_apache_doc_root/$var_url_mapbender/app/config/config.yml.dist > config.yml
#echo "            # EDIT: Database connection to postgis" >> config.yml
#echo "            search_db:" >> config.yml
#echo "                driver:   %postgis_database_driver%" >> config.yml
#echo "                host:     %postgis_database_host%" >> config.yml
#echo "                port:     %postgis_database_port%" >> config.yml
#echo "                dbname:   %postgis_database_name%" >> config.yml
#echo "                path:     %postgis_database_path%" >> config.yml
#echo "                user:     %postgis_database_user%" >> config.yml
#echo "                password: %postgis_database_password%" >> config.yml
#echo "                charset:  UTF8" >> config.yml
#echo "                logging: %kernel.debug%" >> config.yml
#echo "                profiling: %kernel.debug%" >> config.yml

#tail -n+56 $path_apache_doc_root/$var_url_mapbender/app/config/config.yml.dist >> config.yml
#mv config.yml $path_apache_doc_root/$var_url_mapbender/app/config/config.yml

# Create database
cd $path_apache_doc_root/$var_url_mapbender
app/console doctrine:database:create
# Create database schema
app/console doctrine:schema:create
# Copy the bundles
app/console assets:install web
# Create admin
app/console fom:user:resetroot --username="$var_roles_admin_name" --password="$var_roles_admin_password" --email="$var_roles_admin_email" --silent
# Insert srs parameters
app/console doctrine:fixtures:load --fixtures=./mapbender/src/Mapbender/CoreBundle/DataFixtures/ORM/Epsg/ --append

# delete old applications
rm app/config/applications/* -R

) 2>&1 | tee -a $log
