#!/bin/bash

# Autor: Tino Schuldt
# Date: 30.11.2017


# Filename of this script
log_name="create_tables"

# Load the project functions and configuration 
source ./head_admin.sh

# decleare config data
file_schema="create_new_schema.sql"
file_relation="create_new_relation.sql"
file_layers="create_new_layers.sql"

# change to tmp
cd ../tmp

# create new tables with SQL-File
(
  if [ ! $var_application_db_schema == "public" ] ; then
    # create new schema for the geodata layers
    echo "-- Execute by create_tables.sh">$file_schema
    echo "-- SQL create new schema">>$file_schema
    echo "">>$file_schema
    echo "-- create new Schema">>$file_schema
    echo "CREATE SCHEMA "$var_application_db_schema";">>$file_schema
    
    # Import SQL-File for new schema
    path_root=`pwd`/..
    /bin/su -l postgres -c "psql -U postgres -d $var_db_name -f $path_root/tmp/$file_schema"
  fi


  # Basic layer tables
  echo "-- Execute by create_tables.sh">$file_relation
  echo "-- SQL create new layers">>$file_relation
  echo "">>$file_relation

  echo "-- create new table person">>$file_relation
  echo "CREATE TABLE "$var_application_db_schema".person (">>$file_relation
  echo "  id SERIAL PRIMARY KEY,">>$file_relation
  echo "  firstname CHARACTER VARYING,">>$file_relation
  echo "  lastname CHARACTER VARYING,">>$file_relation
  echo "  email CHARACTER VARYING,">>$file_relation
  echo "  phone CHARACTER VARYING">>$file_relation
  echo ");">>$file_relation
  echo "">>$file_relation

  echo "-- create new table type">>$file_relation
  echo "CREATE TABLE "$var_application_db_schema".type (">>$file_relation
  echo "  id SERIAL PRIMARY KEY,">>$file_relation
  echo "  name CHARACTER VARYING">>$file_relation
  echo ");">>$file_relation
  echo "">>$file_relation
  
  # Import SQL-File for new layers
  path_root=`pwd`/..
  /bin/su -l postgres -c "psql -U postgres -d $var_db_name -f $path_root/tmp/$file_relation"
  
  
  
  # Basic layer tables
  echo "-- Execute by create_tables.sh">$file_layers
  echo "-- SQL create new layers">>$file_layers
  echo "">>$file_layers
  
  echo "-- create new table poi">>$file_layers
  echo "CREATE TABLE "$var_application_db_schema".poi (">>$file_layers
  echo "  gid SERIAL PRIMARY KEY,">>$file_layers
  echo "  id INTEGER,">>$file_layers
  echo "  collected DATE,">>$file_layers
  echo "  typeid INTEGER,">>$file_layers
  echo "  personid INTEGER,">>$file_layers
  echo "  geom geometry(POINTZ,$var_application_srid),">>$file_layers
  echo "  FOREIGN KEY (typeid) REFERENCES "$var_application_db_schema".type(id),">>$file_layers
  echo "  FOREIGN KEY (personid) REFERENCES "$var_application_db_schema".person(id)">>$file_layers
  echo ");">>$file_layers
  echo "">>$file_layers
  
  echo "-- create new table polygon">>$file_layers
  echo "CREATE TABLE "$var_application_db_schema".polygon (">>$file_layers
  echo "  gid SERIAL PRIMARY KEY,">>$file_layers
  echo "  id INTEGER,">>$file_layers
  echo "  collected DATE,">>$file_layers
  echo "  orientation FLOAT,">>$file_layers
  echo "  openingmax FLOAT,">>$file_layers
  echo "  openingmin FLOAT,">>$file_layers
  echo "  depth FLOAT,">>$file_layers
  echo "  personid INTEGER,">>$file_layers
  echo "  geom geometry(POLYGONZ,$var_application_srid),">>$file_layers
  echo "  FOREIGN KEY (personid) REFERENCES "$var_application_db_schema".person(id)">>$file_layers
  echo ");">>$file_layers
  echo "">>$file_layers
  
  # Import SQL-File for new layers
  path_root=`pwd`/..
  /bin/su -l postgres -c "psql -U postgres -d $var_db_name -f $path_root/tmp/$file_layers"

) 2>&1 | tee -a $log


