#!/bin/bash

# Autor: Tino Schuldt
# Date: 30.11.2017


# Filename of this script
log_name="create_views"

# Load the project functions and configuration 
source ./head_admin.sh

# decleare config data
file_views="create_new_views.sql"

# change to tmp
cd ../tmp

# create new tables with SQL-File
(

  # Views
  echo "-- Execute by create_views.sh">$file_views
  echo "-- SQL create new views">>$file_views
  echo "">>$file_views

  echo "-- create new view [poi_all] for all POIs">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".poi_all AS">>$file_views
  echo "SELECT gid, poi.id, collected, EXTRACT('YEAR' FROM collected)::integer AS year, type.name as type, CONCAT(CONCAT(person.firstname, ' '), person.lastname) AS person, ST_X(geom) AS x, ST_Y(geom) AS y, ST_Z(geom) AS z, ST_Force2D(geom) as geom2d, geom as geom3d">>$file_views
  echo "FROM "$var_application_db_schema".poi">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".person ON "$var_application_db_schema".poi.personid = "$var_application_db_schema".person.id">>$file_views  
  echo "LEFT JOIN "$var_application_db_schema".type ON "$var_application_db_schema".poi.typeid = "$var_application_db_schema".type.id ;">>$file_views  
  echo "">>$file_views  
  
  echo "-- create new view [poi_year] the last POI on the years">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".poi_year AS">>$file_views
  echo "SELECT a.*">>$file_views
  echo "FROM "$var_application_db_schema".poi_all a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".poi_all b">>$file_views
  echo "  ON b.year = a.year">>$file_views
  echo "  AND b.collected > a.collected">>$file_views
  echo "  AND b.id = a.id">>$file_views
  echo "WHERE b.year IS NULL">>$file_views
  echo "ORDER BY a.id, a.year ;">>$file_views
  echo "">>$file_views  
  
  echo "-- create new view [poi_year_distance] for the yearly POIs with distance and a linestring to the next poi">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".poi_year_distance AS">>$file_views
  echo "SELECT a.*, b.collected AS collected_from, ST_Distance(a.geom3d::geography, b.geom3d::geography) AS distance, ST_MakeLine(b.geom3d, a.geom3d) AS geom_distance">>$file_views
  echo "FROM "$var_application_db_schema".poi_year a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".poi_year b">>$file_views
  echo "  ON b.id = a.id">>$file_views
  echo "  AND b.gid != a.gid">>$file_views
  echo "  AND b.collected < a.collected">>$file_views
  echo "  AND b.year >= (a.year - 1)">>$file_views
  echo "ORDER BY a.id, a.year ;">>$file_views
  echo "">>$file_views
  
  echo "-- create new view [poi_year_distance_avg] for the yearly POIs with distance and a linestring to the next poi">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".poi_year_distance_avg AS">>$file_views
  echo "SELECT a.*, b.distance_max, b.distance_anz, b.distance_avg">>$file_views
  echo "FROM "$var_application_db_schema".poi_year_distance a, ">>$file_views
  echo "  (SELECT id, SUM(distance) AS distance_max, COUNT(distance) AS distance_anz, AVG(distance) AS distance_avg">>$file_views  
  echo "  FROM "$var_application_db_schema".poi_year_distance">>$file_views
  echo "  GROUP BY id) b">>$file_views
  echo "WHERE a.id = b.id">>$file_views
  echo "ORDER BY a.id, a.year ;">>$file_views
  echo "">>$file_views
  
  
  
  echo "-- create new view [poi_max] for the first and last POIs">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".poi_max AS">>$file_views
  echo "SELECT 2 AS nid, a.*">>$file_views
  echo "FROM "$var_application_db_schema".poi_all a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".poi_all b">>$file_views
  echo "  ON b.collected > a.collected">>$file_views
  echo "  AND b.id = a.id">>$file_views
  echo "WHERE b.collected IS NULL">>$file_views
  echo "UNION">>$file_views
  echo "SELECT 1 AS nid, a.*">>$file_views
  echo "FROM "$var_application_db_schema".poi_all a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".poi_all b">>$file_views
  echo "  ON b.collected < a.collected">>$file_views
  echo "  AND b.id = a.id">>$file_views
  echo "WHERE b.collected IS NULL ;">>$file_views
  echo "">>$file_views
  
  echo "-- create new view [poi_max_distance] for the first and last POIs with distance and a linestring from first and last poi">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".poi_max_distance AS">>$file_views
  echo "SELECT a.*, b.collected AS collected_from, ST_Distance(a.geom3d::geography, b.geom3d::geography) AS distance, ST_MakeLine(a.geom3d, b.geom3d) AS geom_distance">>$file_views
  echo "FROM "$var_application_db_schema".poi_max a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".poi_max b">>$file_views
  echo "  ON a.id = b.id">>$file_views
  echo "  AND a.nid != b.nid">>$file_views
  echo "ORDER BY a.id, a.year ;">>$file_views
  echo "">>$file_views
  
  
  
  
  
  echo "-- create new view [polygon_all] for all POLYGONs">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".polygon_all AS">>$file_views
  echo "SELECT gid, polygon.id, collected, EXTRACT('YEAR' FROM collected)::integer AS year, orientation, openingmax, openingmin, depth, CONCAT(CONCAT(person.firstname, ' '), person.lastname) AS person, ST_Area(geom::geography) AS area, ST_Perimeter(geom::geography) AS perimeter, ST_Force2D(geom) AS geom2d, geom AS geom3d, ST_Centroid(geom) AS geom_centroid, ST_X(ST_Centroid(geom)) AS centroid_x, ST_Y(ST_Centroid(geom)) AS centroid_y">>$file_views
  echo "FROM "$var_application_db_schema".polygon">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".person ON "$var_application_db_schema".polygon.personid = "$var_application_db_schema".person.id ;">>$file_views
  echo "">>$file_views
  
  
  echo "-- create new view [polygon_year] the last POLYGON on the years">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".polygon_year AS">>$file_views
  echo "SELECT a.*">>$file_views
  echo "FROM "$var_application_db_schema".polygon_all a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".polygon_all b">>$file_views
  echo "  ON b.year = a.year">>$file_views
  echo "  AND b.collected > a.collected">>$file_views
  echo "  AND b.id = a.id">>$file_views
  echo "WHERE b.year IS NULL">>$file_views
  echo "ORDER BY a.id, a.year ;">>$file_views
  echo "">>$file_views
  
  echo "-- create new view [polygon_year_distance] for the yearly POLYGONs with centroid distance and a linestring from first and last centroid poi">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".polygon_year_distance AS">>$file_views
  echo "SELECT a.*, b.collected AS collected_from, ST_Distance(a.geom_centroid::geography, b.geom_centroid::geography) AS centroid_distance, ST_MakeLine(b.geom_centroid, a.geom_centroid) AS geom_centroid_distance, ST_Area(ST_Difference(a.geom3d, b.geom3d)::geography) AS difference_area, ST_Difference(a.geom3d, b.geom3d) AS geom_difference">>$file_views
  echo "FROM "$var_application_db_schema".polygon_year a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".polygon_year b">>$file_views
  echo "  ON b.id = a.id">>$file_views
  echo "  AND b.gid != a.gid">>$file_views
  echo "  AND b.collected < a.collected">>$file_views
  echo "  AND b.year >= (a.year - 1)">>$file_views
  echo "ORDER BY a.id, a.year ;">>$file_views
  echo "">>$file_views
  
  echo "-- create new view [polygon_year_distance_avg] for the yearly POLYGONs with centroid distance and a linestring from first and last centroid poi">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".polygon_year_distance_avg AS">>$file_views
  echo "SELECT a.*, b.difference_area_max, b.difference_area_anz, b.difference_area_avg">>$file_views
  echo "FROM "$var_application_db_schema".polygon_year_distance a, ">>$file_views
  echo "  (SELECT id, SUM(difference_area) AS difference_area_max, COUNT(difference_area) AS difference_area_anz, AVG(difference_area) AS difference_area_avg">>$file_views  
  echo "  FROM "$var_application_db_schema".polygon_year_distance">>$file_views
  echo "  GROUP BY id) b">>$file_views
  echo "WHERE a.id = b.id">>$file_views
  echo "ORDER BY a.id, a.year ;">>$file_views
  echo "">>$file_views
  
  
  
  echo "-- create new view [polygon_max] for the first and last POLYGONs">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".polygon_max AS">>$file_views
  echo "SELECT 2 AS nid, a.*">>$file_views
  echo "FROM "$var_application_db_schema".polygon_all a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".polygon_all b">>$file_views
  echo "  ON b.collected > a.collected">>$file_views
  echo "  AND b.id = a.id">>$file_views
  echo "WHERE b.collected IS NULL">>$file_views
  echo "UNION">>$file_views
  echo "SELECT 1 AS nid, a.*">>$file_views
  echo "FROM "$var_application_db_schema".polygon_all a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".polygon_all b">>$file_views
  echo "  ON b.collected < a.collected">>$file_views
  echo "  AND b.id = a.id">>$file_views
  echo "WHERE b.collected IS NULL ;">>$file_views
  echo "">>$file_views
  
  echo "-- create new view [polygon_max_distance] for the first and last POLYGONs with centroid distance and a linestring from first and last centroid poi and an intersect of both geometrys">>$file_views
  echo "CREATE VIEW "$var_application_db_schema".polygon_max_distance AS">>$file_views
  echo "SELECT a.*, b.collected AS collected_from, ST_Distance(a.geom_centroid::geography, b.geom_centroid::geography) AS centroid_distance, ST_MakeLine(a.geom_centroid, b.geom_centroid) AS geom_centroid_distance, ST_Area(ST_Difference(b.geom3d, a.geom3d)::geography) AS difference_area, ST_Difference(b.geom3d, a.geom3d) AS geom_difference">>$file_views
  echo "FROM "$var_application_db_schema".polygon_max a">>$file_views
  echo "LEFT JOIN "$var_application_db_schema".polygon_max b">>$file_views
  echo "  ON a.id = b.id">>$file_views
  echo "  AND a.nid != b.nid">>$file_views
  echo "ORDER BY a.id, a.year ;">>$file_views

  # Import SQL-File for new views
  path_root=`pwd`/..
  /bin/su -l postgres -c "psql -U postgres -d $var_db_name -f $path_root/tmp/$file_views"

) 2>&1 | tee -a $log


