#!/bin/bash

# Autor: Tino Schuldt
# Date: 30.11.2017


# Filename of this script
log_name="install_tinyows"

# Load the project functions and configuration 
source ./head_admin.sh

# Function to install the packages in the configuration
(
installPackage $pkg_gcc
installPackage $pkg_libxml_dev
installPackage $pkg_flex
installPackage $pkg_make
installPackage $pkg_autoconf
installPackage $pkg_postgresql_server_dev

# unpack to the tmp directory
cd ../tmp
tar -xzf ../download/$pkg_tinyows.tar.gz

# configure tinyows
cd $pkg_tinyows
autoconf
if [ $var_enable_fcgi == true ] ; then
  ./configure --with-fcgi
else
  ./configure
fi

make
make install

# copy config file to etc & tinyows to cgi-bin
cp demo/tinyows.xml /etc/tinyows.xml
mkdir $path_cgi_bin/$var_tinyows_path/
cp tinyows $path_cgi_bin/$var_tinyows_path/tinyows

# delete tmp data
cd ..
rm -R $pkg_TinyOWS

# check tinyows file in cgi-bin
if ! [ -e $path_cgi_bin/$var_tinyows_path/tinyows ] ; then
  echo "ERR: tinyows is not in the CGI-BIN ($path_cgi_bin/$var_tinyows_path) directory."
  exit 1
fi

# create basic authentication for WFS-T
path=/etc/apache2/sites-available/$var_sitesavailable_tinyows
echo "<Directory $path_cgi_bin/$var_tinyows_path/>">$path
echo "    AuthType Basic">>$path
echo "    AuthName \"Authentication for WFS-T\"">>$path
echo "    AuthUserFile /etc/apache2/.htpasswd">>$path
echo "    require valid-user">>$path
echo "</Directory>">>$path

# Create a User
htpasswd -c -b /etc/apache2/.htpasswd $var_tinyows_name $var_tinyows_password

# Enable a2ensite
a2ensite $var_sitesavailable_tinyows

# Reload Apache2
service apache2 reload

  

) 2>&1 | tee -a $log
